@@ -28,11 +28,12 @@ performs user or customer user authorization
 
     my ( $UserID, $UserType ) = $CommonObject->Auth(
         Data => {
-            SessionID         => 'AValidSessionIDValue'     # the ID of the user session
-            UserLogin         => 'Agent',                   # if no SessionID is given UserLogin or
-                                                            #   CustomerUserLogin is required
-            CustomerUserLogin => 'Customer',
-            Password  => 'some password',                   # user password
+            SessionID         => 'AValidSessionIDValue',    # the ID of the user session
+            UserLogin         => 'Agent1',                  # optional, provide UserLogin or CustomerUserLogin
+            # or
+            CustomerUserLogin => 'Customer1',               # optional, provide UserLogin or CustomerUserLogin
+
+            Password          => 'some password',           # user password
         },
     );
 
@@ -183,8 +184,8 @@ sub _AuthUser {
 performs customer user authentication
 
     my $UserID = $CommonObject->_AuthCustomerUser(
-        UserLogin => 'Agent',
-        Password  => 'some password',           # plain text password
+        CustomerUserLogin' => 'Customer1',
+        Password           => 'some password',           # plain text password
     );
 
     returns
